VeoProfile class

Inheritance

Constructors

VeoProfile({Key? key, required String appName, Widget? appIcon, String title = "Profile", String subtitle = "Manage your profile information", String fullNamePlaceholder = "Full Name", String emailPlaceholder = "Email", String phonePlaceholder = "Phone Number", String bioPlaceholder = "Bio", String saveButtonTitle = "Save Changes", String changePhotoButtonTitle = "Change Photo", String logoutButtonTitle = "Logout", bool showToast = false, String pleaseFillRequiredFieldsMessage = "Please fill in all required fields!", String profileUpdatedMessage = "Profile updated successfully!", String? avatarUrl, Map<String, String>? initialData, Future<void> onSaveProfile(Map<String, String> data, String? newAvatarPath)?, Future<void> onLogout()?, VoidCallback? onPhotoChanged, VoidCallback? onSaveSuccess, dynamic onSaveError(String error)?})
const

Properties

appIcon Widget?
final
final
appName String
final
avatarUrl String?
final
bioPlaceholder String
final
changePhotoButtonTitle String
final
emailPlaceholder String
final
fullNamePlaceholder String
final
hashCode int
The hash code for this object.
no setterinherited
initialData Map<String, String>?
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
logoutButtonTitle String
final
onLogout Future<void> Function()?
final
onPhotoChanged VoidCallback?
final
onSaveError → dynamic Function(String error)?
final
onSaveProfile Future<void> Function(Map<String, String> data, String? newAvatarPath)?
final
onSaveSuccess VoidCallback?
final
phonePlaceholder String
final
pleaseFillRequiredFieldsMessage String
final
profileUpdatedMessage String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
saveButtonTitle String
final
showToast bool
final
subtitle String
final
title String
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _VeoProfileState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited